    % The JXYLine class defines a region where current data will be exported.
    %
    % Usage:
    %   JXYLine(isVertical,thePosition)
    %       If isVertical is true then it is a vertical
    %       line at the X coordinate thePosition. If
    %       isVertical is false it is a horizontal line
    %       at the Y coordinate thePosition.
    %
    % Example:
    %   JXYLine(true,330)
    %   JXYLine(false,100)
    %
    % See also JXYRequest, JXYRectange

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% SonnetLab, all included documentation, all included examples
% and all other files (unless otherwise specified) are copyrighted by Sonnet Software
% in 2011 with all rights reserved.
%
% THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS". ANY AND
% ALL EXPRESS OR IMPLIED WARRANTIES ARE DISCLAIMED. UNDER NO CIRCUMSTANCES AND UNDER
% NO LEGAL THEORY, TORT, CONTRACT, OR OTHERWISE, SHALL THE COPYWRITE HOLDERS,  CONTRIBUTORS,
% MATLAB, OR SONNET SOFTWARE BE LIABLE FOR ANY DIRECT, INDIRECT, SPECIAL, INCIDENTAL, OR
% CONSEQUENTIAL DAMAGES OF ANY CHARACTER INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS OF
% GOODWILL, WORK STOPPAGE, COMPUTER FAILURE OR MALFUNCTION, OR ANY AND ALL OTHER COMMERCIAL
% DAMAGES OR LOSSES, OR FOR ANY DAMAGES EVEN IF THE COPYWRITE HOLDERS, CONTRIBUTORS, MATLAB,
% OR SONNET SOFTWARE HAVE BEEN INFORMED OF THE POSSIBILITY OF SUCH DAMAGES, OR FOR ANY CLAIM
% BY ANY OTHER PARTY.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

classdef JXYLine < handle

    properties
        Vertical
        Position
    end
    
    methods
        function obj=JXYLine(isVertical,thePosition)
            obj.Vertical=isVertical;
            obj.Position=thePosition;
        end
        
        function write(obj,theDom,theRequest)
            
            aRegion = theDom.createElement('Region');
            theRequest.appendChild(aRegion);
            
            aStyle=theDom.createAttribute('Style');
            aStyle.setNodeValue('Line');
            aRegion.setAttributeNode(aStyle);
            
            aVertical=theDom.createAttribute('Vertical');
            if obj.Vertical
                aVertical.setNodeValue('Yes');
            else
                aVertical.setNodeValue('No');
            end
            aRegion.setAttributeNode(aVertical);
            
            aPosition=theDom.createAttribute('Position');
            aPosition.setNodeValue(num2str(obj.Position));
            aRegion.setAttributeNode(aPosition);
        end
    end
end

